<?php
/**
 * Plugin Name: Global Multisite Search
 * Plugin URI: https://bitbucket.org/devshuvo/global-multisite-search/ 
 * Bitbucket Plugin URI: https://bitbucket.org/devshuvo/global-multisite-search/
 * Description: Easily search through all blogs into your WordPress Multisite by post title, post content or post author.
 * Version: 1.0.1
 * Author: Akhtarujjaman Shuvo
 * Author URI: https://www.facebook.com/suvobd.ml
 * Text Domain: wpgms
 * Domain Path: /lang
 *
 * @package Global Multisite Search
 */

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

require_once( dirname( __FILE__ ) . '/includes/wpgms-shortcode.php' );

function wpgms_enqueue_styles() {

	wp_enqueue_style( 'wpgms-styles', plugin_dir_url(__FILE__).'css/gms-styles.css' );

 	wp_enqueue_script( 'wpgms-scripts', plugin_dir_url(__FILE__).'js/wpgms-scripts.js', array('jquery') );

	wp_localize_script( 'wpgms-scripts', 'wpgms_ajax_params', 
		array(
	        'wpgms_ajax_nonce' => wp_create_nonce( 'wpgms_ajax_nonce' ),
	        'wpgms_ajax_url' => admin_url( 'admin-ajax.php' )
	    )
    );
}
add_action( 'wp_enqueue_scripts', 'wpgms_enqueue_styles' );

//ajax actions
add_action('wp_ajax_wpgms_ajax_posts', 'wpgms_ajax_result_function');
add_action('wp_ajax_nopriv_wpgms_ajax_posts', 'wpgms_ajax_result_function');

//ajax main function
function wpgms_ajax_result_function(){

	check_ajax_referer( 'wpgms_ajax_nonce', 'wpgms_ajax_nonce', false );
	
	$queryText = sanitize_text_field( esc_attr( $_POST['queryText'] ) );

	$sites = array( 1, 2, 3,4,5,6 );

	$all_posts = array();

	$args = array( 
		'post_type' => 'post',
		's' => $queryText
	);


	foreach( $sites as $site ) :

		switch_to_blog( $site );
		$posts = get_posts( $args );

		foreach( $posts as $post ) : setup_postdata($post);
			
			$post->permalink = get_permalink( $post->ID );

			$post->title = get_the_title( $post->ID );
				        
			$all_posts[] = $post;

			$result = '<article site-id="'.$site.'" id="post-'.$post->ID.'" style="padding-top:30px;clear:both;">';
						
				$result .= '<div class="entry-title-header">';
						
					$result .= '<h2 class="entry-title"><a href="'.$post->permalink.'" rel="bookmark">'.$post->title.'</a></h2>';
						
				$result .= '</div>';

				$result .= '<div class="entry-summary">';

					if ( has_post_thumbnail( $post->ID ) ) {
						$result .= '<div class="wpgms-thumb-area">
						<a href="'.$post->permalink.'" title="'.$post->title.'">';
					    	$result .= get_the_post_thumbnail( $post->ID, 'thumbnail', array( 'class' => 'alignleft' ) );
					    $result .= '</a></div>';
					}

				$result .= get_the_excerpt( $post->ID ).'</div>';

			$result .= '</article>';

			echo $result;

		endforeach;

		restore_current_blog();

	endforeach;

	wp_die();
}